/*********************************************************************
*               SEGGER MICROCONTROLLER SYSTEME GmbH                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2007  SEGGER Microcontroller Systeme GmbH         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS version: 3.52a                                         *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for RENESAS SH7086 Starterkit
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define _NUM_LEDS        (4)

/****** SFRs and identifiers used for LED demo **********************/

#define PFC    (*(volatile unsigned int *) 0xFFFFD104)    /* PFC    */
#define PA     (*(volatile unsigned int *) 0xFFFFD100)    /* Port A */

/****** Assign LEDs to Ports ****************************************/

#define _LEDPORT_DR     (PA)

#define _LED0_BIT       (20)                // first LED = LED0
#define _LED_MASK       ((1 << _NUM_LEDS) - 1)
#define _LED_MASK_ALL   (_LED_MASK << _LED0_BIT)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  PFC         |= _LED_MASK_ALL;   /* Enable LED-Port            */
  _LEDPORT_DR |= _LED_MASK_ALL;   /* Initially switch LEDs off  */
  
}

/*********************************************************************
*
*       LED switching routines
*       LEDs are switched on with low level on port lines
*/
void BSP_SetLED(int Index) {
  Index &= _LED_MASK;
  _LEDPORT_DR &= ~(1 << (Index + _LED0_BIT));    /* Switch on LED  */
}

void BSP_ClrLED(int Index) {
  Index &= _LED_MASK;
  _LEDPORT_DR |=  (1 << (Index + _LED0_BIT));    /* Switch off LED */
}

void BSP_ToggleLED(int Index) {
  Index &= _LED_MASK;
  _LEDPORT_DR ^= (1 << (Index + _LED0_BIT));
}

/****** EOF *********************************************************/


