/***********************************************************************************
FILE NAME  	: hwsetup.c

DESCRIPTION	: Sets up RSK hardware.

Copyright   : 2006 Renesas Technology Europe Ltd.
			  2006 Renesas Technology Corporation.
			  All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
06.12.2006 RTE-NPS First Release.
***********************************************************************************/

/***********************************************************************************
System Includes
***********************************************************************************/
/*	Following header file provides access to intrinsic functions to control interrupt
	levels. */
#include <machine.h>

/***********************************************************************************
User Includes
***********************************************************************************/
/* Following header file provides a structure to access all of the device registers. */
#include "iodefine.h"
/* Following header file provides function prototype for hardware setup function. */
#include "hwsetup.h"
/* Following header file provides function prototype for hardware interrupts function. */
#include "interrupts.h"

/***********************************************************************************
*		Local functions
*
************************************************************************************
*/

/***********************************************************************************
Function Name: 	ConfigureOperatingFrequency
Description:	Sets up operating speed
Parameters: 	none
Return value: 	none
***********************************************************************************/
static void _ConfigureOperatingFrequency(void) {
/* Set CPU PLL operating frequencies. Changes to the peripheral clock will	require
changes to the debugger and flash kernel BRR settings.
REF: HMONSerialConfigUser.h define for SCI_CFG_BRR */

	/* Setting FRQCR: IFC=80MHz, BFC & PFC = 40MHz, MIFC=80MHz, MPFC=40MHz */
	CPG.FRQCR.WORD = 0x0241;
}
/***********************************************************************************
End of function ConfigureOperatingFrequency
***********************************************************************************/

/***********************************************************************************
Function Name: 	ConfigurePortPins
Description:	Configures port pins.
Parameters: 	none
Return value: 	none
***********************************************************************************/

static void _ConfigurePortPins(void) {
  /* Port pins default to inputs. Initialization of outputs may be added here */

}

/***********************************************************************************
Function Name: 	EnablePeripheralModules
Description:	Enables Peripheral Modules before use
Parameters: 	none
Return value: 	none
***********************************************************************************/

static void _EnablePeripheralModules(void) {

}

/***********************************************************************************
*
*		Global functions
*
************************************************************************************
*/

/***********************************************************************************
Function Name: 	HardwareSetup
Description:	Sets up hardware
Parameters:		none
Return value:	none
***********************************************************************************/

void HardwareSetup(void) {
  _ConfigureOperatingFrequency();
  _ConfigurePortPins();
  _EnablePeripheralModules();
  ConfigureInterrupts();
}

/**********************************************************************************
End of file
***********************************************************************************/
