/***********************************************************************************
FILE NAME   : resetprg.c

DESCRIPTION	: Reset Initialisation Function.
			  The user's program will start in this file.

Copyright   : 2006 Renesas Technology Europe Ltd.
			  2006 Renesas Technology Corporation.
			  All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
06.12.2006 RTE-NPS First Release.
***********************************************************************************/

/***********************************************************************************
Compiler Directives
***********************************************************************************/
/* '#pragma section' instructs the linker to place all subsequent code in the named
section. This can be used to relocate code in the memory map. This directive should
be used when debugging code in RAM to provide a section name that can be refernced
in the build | toolchain | linker | section settings.
Use of the directive without the section name will reset the section to default.*/
#pragma section ResetPRG

/***********************************************************************************
System Includes
***********************************************************************************/
/* Following header file provides access to intrinsic functions to control interrupt
	levels. */
#include <machine.h>
/* Following header file provides access to intrinsic functions _INITSCT(). */
#include <_h_c_lib.h>

/*  Following header file is used by __entry directive to set the initial stack pointer.
The value in this file should only be changed if relocating and / or changing the
size of the stack. */
#include "stacksct.h"

/***********************************************************************************
User Includes
***********************************************************************************/
/* iodefine.h provides a structure to access all of the device registers. */
#include "iodefine.h"
/* Following header file provides prototype for hardware setup function.	*/
#include "hwsetup.h"
/* Following header file provides prototype for main() function.	*/
#include "main.h"

/***********************************************************************************
User Program Code
***********************************************************************************/
void Initialise(void);

/***********************************************************************************
ISR Name	: PowerON_Reset
Description	: Power on reset function.
		This function executes following to power on reset.
		It first calls hardware initialisation function & then 'main()' function.
Parameters	: none
Return value: none
***********************************************************************************/
void Initialise(void) {
	/* Initialize the Vector Base Register with the base address of exception handling
	   vector table. */
	set_vbr((void *)((char *)0));

	/*	Copy initilized data from ROM to RAM. 
		dbsct.c file will be used by this function	 */
	_INITSCT();

	/* Set up the hardware	*/
	HardwareSetup();

	/* Call the user function */
	main();
	
	while(1)
	{
		/* This function must never exit */
	}
}

/***********************************************************************************
User Vectors for the start of HMON
***********************************************************************************/
/* This code is only required for debug with HMon */
/* This define is set globally for the build configuration in the tool chain options
*/
#ifdef HMON_Debug

/* The folowing code populates the section User_Vectors with the address of the
users code start point. This value is referenced by HMon when instructed to perform
a code reset. The address ofthe (C)User_Vectors section must be entered in the
HMONConfigUser.H file against the HMON_POWER_ON_RESET_PTR_PTR definition. */
#pragma section User_Vectors

	void * const UserResetVect = (void *) Initialise;

#pragma section

#endif

/**********************************************************************************
End of file
***********************************************************************************/
