/***********************************************************************************
FILE NAME  	: HMONConfigUser.h

DESCRIPTION : User modifiable configuration options for the HMON Monitor
			  This file contains configuration options which you should customise for your
			  system device type, host to target communications, and overall behaviour.

CPU Type	: SH7086

Copyright   : 2006 Renesas Technology Europe Ltd.
			  2006 Renesas Technology Corporation.
			  All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
06.12.2006 RTE-NPS First Release.
***********************************************************************************/

#ifndef HMONCONFIGUSER
#define HMONCONFIGUSER

/**********************************************************************************
Defines
***********************************************************************************/
/* Set this to a pointer to a pointer to the start address of the
   user program for a power-on reset */

#define HMON_POWER_ON_RESET_PTR_PTR		0x800

/* Set this to the address that the stack pointer should
   be set to following a power-on reset */

#define HMON_POWER_ON_RESET_STACK_PTR	0XFFFFC000

/* Set this to a pointer to a pointer to the start address of the
   user program for a manual reset */

/*WIZARD COMMENT START
Not Applicable
WIZARD COMMENT END*/

#define HMON_MANUAL_RESET_PTR_PTR		0x800

/* Set this to the address that the stack pointer should
   be set to following a power-on reset */

/*WIZARD COMMENT START
Not Applicable
WIZARD COMMENT END*/

#define HMON_MANUAL_RESET_STACK_PTR		0XFFFFC000

/* These values state how the CPU traps are mapped onto HMON
   operations. These must match the setup of the traps in the
   vector table */
#define HMON_COMPILED_IN_BREAKPOINT_TRAP    32
#define HMON_CONSOLE_OUTPUT_TRAP            33
#define HMON_SOFTWARE_BREAKPOINT_TRAP       34
#define HMON_MONITOR_INITIALISATION_TRAP    35

/* This should be set to the software breakpoint instruction
   (TRAPA or similar). The host uses this to perform PC breakpoints
   in RAM code, by replacing the instruction at the location with this
   opcode.
*/

/* This is "trapa #2" */
#define HMON_SOFTWARE_BREAKPOINT_OPCODE		0XC322

/* This should be set to the compiled-in breakpoint instruction
   (TRAPA or similar). This can be compiled into user programs as
   a permanent breakpoint	*/

/* This is "trapa #0" */
#define HMON_COMPILED_IN_BREAKPOINT_OPCODE	0XC320

/* Default HMON step break interrupt level
   This must be set to 1 for H8300H series as there is no IPR settings
 */
/* Only applicable in int mode 2 */

/* HMON interrupt level should be just a lower than serial interrupt level */
#define HMON_DEFAULT_INTERRUPT_LEVEL 	0XD

/* This setting determines how the monitor will start.
   Set to HMON_STARTUP_HMON to indicate that when started, the
   monitor should await commands. HMON_STARTUP_USER indicates
   that it should immediately run the user program upon startup.
 */

#define HMON_STARTUP_OPTION			eHMon_StartHmon
//#define HMON_STARTUP_OPTION			eHMon_StartUser

#endif  /* #ifndef HMONCONFIGUSER */
/**********************************************************************************
End  Of File
***********************************************************************************/
