/***********************************************************************************
FILE NAME	: HMONConfigUserStruct.h

Description	: Contains structure(s) and enumeration(s) that are shared between
			  library and user configuration application.

			  NOTE: This file should not be modified.

CPU Type	: SH7086
Copyright   : 2006 Renesas Technology Europe Ltd.
			  2006 Renesas Technology Corporation.
			  All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
06.12.2006 RTE-NPS First Release.
***********************************************************************************/

#ifndef HMONCONFIGUSERSTRUCT
#define HMONCONFIGUSERSTRUCT

/**********************************************************************************
Enumerated Types
***********************************************************************************/
/* Enumerated identifiers for monitor startup mode */
enum EHMon_Startup
{
    /* Monitor starts up and awaits commands   */
	eHMon_StartHmon = 0,

    /* Monitor starts up and runs user program */
	eHMon_StartUser
};


/**********************************************************************************
Typedefs
***********************************************************************************/
#ifndef UINT8
#define UINT8 unsigned char
#endif

#ifndef UINT16
#define UINT16 unsigned short
#endif

#ifndef UINT32
#define UINT32 unsigned long
#endif

#ifndef INT16
#define INT16 signed short
#endif


/* Structure describing the configurable capabilities and configuration of the current system */
typedef struct _HMONCapabilityStructureUser
{
    UINT32   ppPowerOnResetUserProgram;
    UINT32   pPowerOnResetUserProgramStack;
    UINT32   ppManualResetUserProgram;
    UINT32   pManualResetUserProgramStack;
    UINT32   unSoftwareBreakPointInstruction;
    UINT32   unCompiledInSoftwareBreakPointInstruction;
    UINT32   ucMonitorInterruptLevel;
    UINT32   ucStartupSequence;
} _HMONCapabilityStructureUser;

/**********************************************************************************
Constant Data
***********************************************************************************/

extern const _HMONCapabilityStructureUser _HMONCapabilityUser;

/**********************************************************************************
Public Functions
***********************************************************************************/

#ifdef __cplusplus
extern "C" {
#endif

/**********************************************************************************
Function Name: _HMONConsoleInputHandler
Description:   Stub function for handling console input. When console input is
               received from the host, HMON will call this function to handle it.
Parameters:    I/O pucBuffer - Pointer to the character array
               IN  nSizeofInputData - The number of console input characters
               OUT pnSizeofOutputData - The number of characters contained in the
                                        reply
Return value:  none
**********************************************************************************/

extern  void _HMONConsoleInputHandler(UINT8 *pucBuffer,
                              INT16 nSizeofInputData,
                              INT16 *pnSizeofOutputData);

/**********************************************************************************
Function Name: _HMONExtendedCommandHandler
Description:   Function for handling extended monitor commands. If the monitor
               recieves any commands from the host that it does not understand,
               it passes the data to this function.
Parameters:    IN  pucInputData - Pointer to the data received from the host
               IN  nSizeofInputData - The number of console input characters
               OUT ppucReturnData - Pointer to a pointer that will be set to the
                                    return data.
               OUT pnSizeofOutputData - Pointer to the number of characters
                                        contained in the reply
Return value:  none
**********************************************************************************/

extern  void _HMONExtendedCommandHandler(UINT8 *pucInputData,
                                 INT16 nSizeofInputData,
                                 UINT8 **ppucReturnData,
                                 INT16 *pnSizeofReturnData);

/**********************************************************************************
Function Name: _HMONFatalError
Description:   This function is called when the monitor encounters an unrecoverable
               error (e.g. communications library failure)
Parameters:    IN  userpc - The PC at which it all went tits up
Return value:  none
**********************************************************************************/

extern  void _HMONFatalError(UINT32 userpc);

/**********************************************************************************
Function Name: _HMONInitVbrAndIvt
Description:   Function to initialise the Vector Base Register and Interrupt Vector
               Table (VBR and IVT) however the user want's them
Parameters:    none
Return value:  none
**********************************************************************************/

extern  void _HMONInitVbrAndIvt(void);

/**********************************************************************************
Function Name: _HMONUserSectionMapping
Description:   Function to initialise any mapped data sections (other than PHMON)
Parameters:    none
Return value:  none
**********************************************************************************/

extern  void _HMONUserSectionMapping(void);

#ifdef __cplusplus
}
#endif

#endif                              /* HMONCONFIGUSERSTRUCT */

/**********************************************************************************
End  Of File
***********************************************************************************/
