/***********************************************************************************
FILE NAME  	: HMONSerialConfigUser.c

DESCRIPTION	: Configuration for the HMON Monitor Serial Library
			  This file contains configuration options which you should customise for your
			  system device type, host to target communications, and overall behaviour.

CPU Type	: SH7086

Copyright   : 2006 Renesas Technology Europe Ltd.
			  2006 Renesas Technology Corporation.
			  All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
06.12.2006 RTE-NPS First Release.
***********************************************************************************/

/**********************************************************************************
System Includes
***********************************************************************************/


/*****************************************************************************
 User Includes
*****************************************************************************/
/* iodefine.h should be included if required by _HMONInitHWSerial to
   configure the serial port	*/
#include "iodefine.h"

#include "HMONSerialConfigUser.h"

/***********************************************************************************
Compiler Directives
***********************************************************************************/

/* This #pragma ensures the structure is kept seperate to the user's area
   and allows monitor to be protected whilst user code changes through the
   GUI memory mapping (user controlled).
*/
#pragma section HMON



/**********************************************************************************
Defines
***********************************************************************************/



/**********************************************************************************
Function Prototypes
***********************************************************************************/

void _HMONSerialIntSetup(WORD a_wIntPriority);

/*****************************************************************************
 Global Data
*****************************************************************************/
/* This structure is used to setup the serial port for debugger comms. */
const ST_SCI_CONFIG _HMONgstHmonDebugPortConfig =
{
	SCI_CFG_BRR,
    SCI_CFG_STOP_1,
    SCI_CFG_PARITY_NONE,
    SCI_CFG_CHAR_8,
    SCI_CFG_BRG_DIV_0,
    SCI_CFG_INT_PRIORITY_14
};

/* Global registers structure for Hmon debug port */
const ST_SCI_PORT _HMONgstSciPort =
{
    /* General SCI port registers */
    P_SCI_SMR,
    P_SCI_BRR,
    P_SCI_SCR,
    P_SCI_TDR,
    P_SCI_SSR,
    P_SCI_RDR,

    /* Interrupt priority register and bit mask/shifts */
	&_HMONSerialIntSetup
};

/**********************************************************************************
Private Functions
***********************************************************************************/
/* This structure is used to modify the IPR or IPC settings
   of the debugger communications to allow the interrupt
   level to be modified as required */
const ST_SCI_IPR _HMONgstSciIpr =
{
	P_SCI_IPR,
    SCI_IPRn_SCI_CLEAR,
    SCI_IPRn_SCI_SHIFT
};


/* Sets the IPR or ICR register as determined by the
   configuration structure and by HMON  */
void _HMONSerialIntSetup(WORD a_wIntPriority)
{
	T_SCI_IPR	wk;

	/* Set the interrupt priority/control register for the SCI channel */
	wk = (T_SCI_IPR)(*_HMONgstSciIpr.ptIPRn & _HMONgstSciIpr.tClearMask);
	*_HMONgstSciIpr.ptIPRn = (T_SCI_IPR)(wk | (a_wIntPriority << SCI_IPRn_SCI_SHIFT) );
}

/**********************************************************************************
Function Name: _HMONInitHWSerial
Description:   Function to initialise the serial port pins
Parameters:    none
Return value:  none
**********************************************************************************/
void _HMONInitHWSerial(void)
{
	unsigned short wk;
	/* User must add code to setup the debugger communications hardware.
	   Typical settings required may include
	   - Module Stop registers
	   - IO Pin Mode
	   - IO Pin Direction */

	/* Setting FRQCR: IFC=80MHz, BFC & PFC = 40MHz, MIFC=80MHz, MPFC=40MHz */
	(*(unsigned short *)0xFFFFE800) = 0x0241;

	/* STBCR3 SCI1 Module stop bit 4 */
	(*(unsigned char *) 0xFFFFE806) &= 0xef;

	/* PAIORL TXD1 Setting as Output port */
	(*(unsigned short *)0xFFFFD106) |= 0x0010;

	/* PACRL2 TXD1 Setting */
	wk = (*(unsigned short *)0xFFFFD114) & 0x7700;
	(*(unsigned short *)0xFFFFD114) = wk | 0x0001;

	/* PACRL1 RXD1 Setting */
	wk = (*(unsigned short *)0xFFFFD116) & 0x0077;
	(*(unsigned short *)0xFFFFD116) = wk | 0x1000;
}

/**********************************************************************************
End of file
***********************************************************************************/
