/***********************************************************************************
FILE NAME  	: HMONSerialConfigUser.h

DESCRIPTION	: Configuration for the HMON Serial Library
		      This file contains configuration options which you should customise for your
		      system device type, host to target communications, and overall behaviour.

CPU Type	: SH7086

Copyright   : 2006 Renesas Technology Europe Ltd.
			  2006 Renesas Technology Corporation.
			  All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
06.12.2006 RTE-NPS First Release.
***********************************************************************************/

#ifndef _HMONSERIALCONFIGUSER_H_INCLUDED_
#define _HMONSERIALCONFIGUSER_H_INCLUDED_

/**********************************************************************************
User Includes
***********************************************************************************/

#include "HMONSerialStruct.h"

/**********************************************************************************
Defines
***********************************************************************************/

/*****************************************************************************
 SCI Configuration Enumerated Constants
*****************************************************************************/
/* Stop Bits */
enum eStopBits
{
    SCI_CFG_STOP_1,
    SCI_CFG_STOP_2
};

/* Parity */
enum eParity
{
    SCI_CFG_PARITY_NONE,
    SCI_CFG_PARITY_ODD,
    SCI_CFG_PARITY_EVEN
};

/* Character Size */
enum eCharSize
{
    SCI_CFG_CHAR_7,
    SCI_CFG_CHAR_8
};

/* Baud Rate Generator Clock Divider */
enum eBRGDivider
{
    SCI_CFG_BRG_DIV_0,
    SCI_CFG_BRG_DIV_1,
    SCI_CFG_BRG_DIV_2,
    SCI_CFG_BRG_DIV_3
};

/* Interrupt priority levels for SCI */
enum eIntPriority
{
    SCI_CFG_INT_PRIORITY_0,
    SCI_CFG_INT_PRIORITY_1,
    SCI_CFG_INT_PRIORITY_2,
    SCI_CFG_INT_PRIORITY_3,
    SCI_CFG_INT_PRIORITY_4,
    SCI_CFG_INT_PRIORITY_5,
    SCI_CFG_INT_PRIORITY_6,
    SCI_CFG_INT_PRIORITY_7,
    SCI_CFG_INT_PRIORITY_8,
    SCI_CFG_INT_PRIORITY_9,
    SCI_CFG_INT_PRIORITY_10,
    SCI_CFG_INT_PRIORITY_11,
    SCI_CFG_INT_PRIORITY_12,
    SCI_CFG_INT_PRIORITY_13,
    SCI_CFG_INT_PRIORITY_14,
    SCI_CFG_INT_PRIORITY_15
};

/*****************************************************************************
 SCI CONFIG
*****************************************************************************/

#define SCI_CFG_STOP			SCI_CFG_STOP_1
#define SCI_CFG_PARITY_NONE		SCI_CFG_PARITY_NONE
#define SCI_CFG_CHAR			SCI_CFG_CHAR_8
#define SCI_CFG_INT_PRIORITY	SCI_CFG_INT_PRIORITY_14


/* BRR calculated with peripheral clk = 40 MHz for 250000*/
#define SCI_CFG_BRR				0X4
#define SCI_CFG_BRG_DIV			SCI_CFG_BRG_DIV_0

/*****************************************************************************
 Include dependant header files
*****************************************************************************/
#include "HMONSerialStruct.h" // Check this needs double includes

void _HMONInitHWSerial(void);
void _HMONSerialIntSetup(WORD a_wIntPriority);

/*****************************************************************************
 SCI Port Inputs (USER CONFIGURABLE)
*****************************************************************************/
/* Address for SMR register             */
#define P_SCI_BASE     0XFFFFC080
/* In bytes between register 1,2 or 4   */
#define P_SCI_OFFSET   0X2

/*****************************************************************************
 SCI Port Registers (CALCULATED ADDRESS POINTERS)
*****************************************************************************/
#define P_SCI_SMR      (volatile BYTE *)(P_SCI_BASE + (P_SCI_OFFSET * 0))
#define P_SCI_BRR      (volatile BYTE *)(P_SCI_BASE + (P_SCI_OFFSET * 1))
#define P_SCI_SCR      (volatile BYTE *)(P_SCI_BASE + (P_SCI_OFFSET * 2))
#define P_SCI_TDR      (volatile BYTE *)(P_SCI_BASE + (P_SCI_OFFSET * 3))
#define P_SCI_SSR      (volatile BYTE *)(P_SCI_BASE + (P_SCI_OFFSET * 4))
#define P_SCI_RDR      (volatile BYTE *)(P_SCI_BASE + (P_SCI_OFFSET * 5))

/*****************************************************************************
 Interrupt Registers and masks for SCI (USER CONFIGURABLE)
*****************************************************************************/
typedef WORD T_SCI_IPR;
typedef volatile T_SCI_IPR* PT_SCI_IPR;

/*Interrupt priority register IPRL address */
#define P_SCI_IPR      (volatile T_SCI_IPR*) 0XFFFFE992

/* Clear priority bits */
#define SCI_IPRn_SCI_CLEAR   (T_SCI_IPR) 0XF0FF

/* Shift priority bits (IPRL11 to IPRL8 = SCI1)*/
#define SCI_IPRn_SCI_SHIFT   (T_SCI_IPR) 0X08

typedef struct st_SciIpr
{
    /* Interrupt priority register */
	PT_SCI_IPR     ptIPRn;
    T_SCI_IPR      tClearMask;
    T_SCI_IPR      tShift;
} ST_SCI_IPR;

#else
#ifdef _WINDOWS
#pragma message ( "Warning : User : Header files nested - HMonSerialConfigUser.h" )
#endif
#endif
/* _HMONSERIALCONFIGUSER_H_INCLUDED_ */

/*****************************************************************************
 End of file
*****************************************************************************/
